import '@zhinjs/plugin-console';
import { Awaitable, Plugin, Bot, Dict } from 'zhin';
import { DataService } from '@zhinjs/plugin-console';
import { UserTable } from '@zhinjs/plugin-database';
declare module '@zhinjs/plugin-database' {
    namespace UserTable {
        interface Types {
            password: string;
            token: string;
            expire: number;
        }
    }
}
declare module '@zhinjs/plugin-console' {
    interface SocketHandle {
        user?: UserAuth;
    }
    namespace Console {
        interface Services {
            user: AuthService;
        }
    }
    interface Events {
        'login/captcha'(this: SocketHandle, user_id: number): Awaitable<UserLogin>;
        'login/password'(this: SocketHandle, user_id: number, password: string): void;
        'login/token'(this: SocketHandle, user_id: number, token: string): void;
        'user/update'(this: SocketHandle, data: UserUpdate): void;
        'user/logout'(this: SocketHandle): void;
    }
}
export type UserAuth = Pick<UserTable.Types, 'user_id' | 'name' | 'authority' | 'token' | 'expire'>;
export type UserLogin = Pick<UserTable.Types, 'user_id' | 'name' | 'token' | 'expire'>;
export type UserUpdate = Partial<Pick<UserTable.Types, 'name' | 'password'>>;
export class AuthService extends DataService<UserAuth> {
    plugin: Plugin;
    private config;
    static using: readonly ["console", "database"];
    constructor(plugin: Plugin, bot: Bot, config: AuthService.Config);
    initLogin(): void;
}
declare namespace AuthService {
    interface Config {
        authTokenExpire?: number;
        loginTokenExpire?: number;
    }
}
declare module 'zhin' {
    interface Bot {
        _messageSent?: TickCounter;
        _messageReceived?: TickCounter;
    }
}
declare module '@zhinjs/plugin-console' {
    namespace Console {
        interface Services {
            bot: BotService;
        }
    }
    interface Events {
        'control/bot-update'(config: Bot.Options): void;
        'control/bot-login'(uin: string, type: 'password' | 'slider' | 'sms', value?: string): void;
    }
}
declare class TickCounter {
    stop: () => void;
    private data;
    private tick;
    constructor(plugin: Plugin);
    add(value?: number): void;
    get(): any;
}
export class BotService extends DataService<Dict<BotService.Data>> {
    plugin: Plugin;
    callbacks: BotService.Extension[];
    constructor(plugin: Plugin, bot: Bot);
    loginBot(uin: string, type: 'password' | 'slider' | 'sms', value?: string): Promise<unknown>;
    updateBot(config: Bot.Options): void;
    extend(callback: BotService.Extension): void;
    get(): Promise<any>;
}
export namespace BotService {
    function initialize(bot: Bot, plugin: Plugin): void;
    type Extension = (bot: Bot) => Partial<Data>;
    interface Data extends Pick<Bot, 'uin' | 'nickname' | 'status'> {
        config: Partial<Bot.Options>;
        messageSent: number;
        messageReceived: number;
    }
}
export const using: string[];
export interface Config {
}
export function install(bot: Bot, config?: Config): void;
declare module '@zhinjs/plugin-console' {
    namespace Console {
        interface Services {
            plugin: PluginService;
        }
    }
}
export class PluginService extends DataService<PluginService.Config> {
    plugin: Plugin;
    private config;
    constructor(plugin: Plugin, bot: Bot, config?: PluginService.Config);
}
export namespace PluginService {
    interface Config {
    }
}
